@@ -66,7 +66,7 @@ def from_dict(
             override_args,
         )
 
-    object = utils.get_object(
+    object, params = utils.get_object(
         cls,
         version,
         installed_version,
@@ -79,6 +79,22 @@ def from_dict(
         # create attribute to signal that object was loaded
         object.__dict__[define.OBJECT_LOADED] = None
 
+    # If function has init decorator, add stream to parameters.
+    # The additional parameter will be popped by the decorator
+    # before the object is created.
+    # If the class does not have a decorator
+    # a TypeError will be raised since we call
+    # the class with an unexpected argument.
+    # Unfortunately, there is no straight-forward way
+    # to check if a method of a class has a decorator
+    # so we have to use a try-except block
+    try:
+        params[define.ROOT_ATTRIBUTE] = root
+        object.__init__(**params)
+    except TypeError:
+        params.pop(define.ROOT_ATTRIBUTE)
+        object.__init__(**params)
+
     return object
 
 
